import ArrowBackIcon from "@mui/icons-material/ArrowBack";
import { IconButton } from "@mui/material";
import React from "react";
import { useParams } from "react-router-dom";
import { NetworkApi, NetworkInfo, NetworkURL } from "../api/NetworksApi";
import { AsyncWidget } from "../widgets/AsyncWidget";
import { RouterLink } from "../widgets/RouterLink";
import { VirtWebRouteContainer } from "../widgets/VirtWebRouteContainer";
import { XMLWidget } from "../widgets/XMLWidget";

export function NetXMLRoute(): React.ReactElement {
  const { uuid } = useParams();

  const [net, setNet] = React.useState<NetworkInfo | undefined>();
  const [src, setSrc] = React.useState<string | undefined>();

  const load = async () => {
    setNet(await NetworkApi.GetSingle(uuid!));
    setSrc(await NetworkApi.GetSingleXML(uuid!));
  };

  return (
    <AsyncWidget
      loadKey={uuid}
      load={load}
      errMsg="Failed to load network information!"
      build={() => <XMLRouteInner net={net!} src={src!} />}
    />
  );
}

function XMLRouteInner(p: {
  net: NetworkInfo;
  src: string;
}): React.ReactElement {
  return (
    <VirtWebRouteContainer
      label={`XML definition of ${p.net.name}`}
      actions={
        <RouterLink to={NetworkURL(p.net)}>
          <IconButton>
            <ArrowBackIcon />
          </IconButton>
        </RouterLink>
      }
    >
      <XMLWidget src={p.src} />
    </VirtWebRouteContainer>
  );
}
